@@ -3,9 +3,9 @@
 
    Model File:  perc.model
 
-   Date:  Fri Feb 23 09:33:16 2018
+   Date:  Sat May  5 11:13:27 2018
 
-   Created by:  "../../mod/mod v6.0.0"
+   Created by:  "../../mod/mod v6.0.1"
     -- a model preprocessor by Don Maszle
    ___________________________________________________
 
@@ -31,7 +31,7 @@
 
    2 Inputs:
      C_inh (is a function)
-     Q_ing (is a function)
+     R_ing (is a function)
 
    36 Parameters:
      PPM_per_mg_per_l = 72.0 / 0.488;
@@ -101,7 +101,7 @@
 
 /* Inputs */
 #define ID_C_inh 0x00000
-#define ID_Q_ing 0x00001
+#define ID_R_ing 0x00001
 
 /* Parameters */
 #define ID_PPM_per_mg_per_l 0x0000e
@@ -147,7 +147,7 @@
 /* For export. Keep track of who we are. */
 char szModelDescFilename[] = "perc.model";
 char szModelSourceFilename[] = __FILE__;
-char szModelGenAndVersion[] = "../../mod/mod v6.0.0";
+char szModelGenAndVersion[] = "../../mod/mod v6.0.1";
 
 /* Externs */
 extern BOOL vbModelReinitd;
@@ -222,7 +222,7 @@ VMMAPSTRCT vrgvmGlo[] = {
   {"Pct_metabolized", (PVOID) &vrgModelVars[ID_Pct_metabolized], ID_OUTPUT | ID_Pct_metabolized},
   {"C_exh_ug", (PVOID) &vrgModelVars[ID_C_exh_ug], ID_OUTPUT | ID_C_exh_ug},
   {"C_inh", (PVOID) &vrgInputs[ID_C_inh], ID_INPUT | ID_C_inh},
-  {"Q_ing", (PVOID) &vrgInputs[ID_Q_ing], ID_INPUT | ID_Q_ing},
+  {"R_ing", (PVOID) &vrgInputs[ID_R_ing], ID_INPUT | ID_R_ing},
   {"PPM_per_mg_per_l", (PVOID) &PPM_per_mg_per_l, ID_PARM | ID_PPM_per_mg_per_l},
   {"mg_per_l_per_PPM", (PVOID) &mg_per_l_per_PPM, ID_PARM | ID_mg_per_l_per_PPM},
   {"InhMag", (PVOID) &InhMag, ID_PARM | ID_InhMag},
@@ -302,21 +302,21 @@ void InitModel(void)
   vrgInputs[ID_C_inh].hTper = 0x40011;
   vrgInputs[ID_C_inh].dVal = 0.0;
   vrgInputs[ID_C_inh].nDoses = 0;
-  vrgInputs[ID_Q_ing].iType = IFN_CONSTANT;
-  vrgInputs[ID_Q_ing].dTStartPeriod = 0;
-  vrgInputs[ID_Q_ing].bOn = FALSE;
-  vrgInputs[ID_Q_ing].dMag = 0.000000;
-  vrgInputs[ID_Q_ing].dT0 = 0.000000;
-  vrgInputs[ID_Q_ing].dTexp = 0.000000;
-  vrgInputs[ID_Q_ing].dDecay = 0.000000;
-  vrgInputs[ID_Q_ing].dTper = 0.000000;
-  vrgInputs[ID_Q_ing].hMag = 0;
-  vrgInputs[ID_Q_ing].hT0 = 0;
-  vrgInputs[ID_Q_ing].hTexp = 0;
-  vrgInputs[ID_Q_ing].hDecay = 0;
-  vrgInputs[ID_Q_ing].hTper = 0;
-  vrgInputs[ID_Q_ing].dVal = 0.0;
-  vrgInputs[ID_Q_ing].nDoses = 0;
+  vrgInputs[ID_R_ing].iType = IFN_CONSTANT;
+  vrgInputs[ID_R_ing].dTStartPeriod = 0;
+  vrgInputs[ID_R_ing].bOn = FALSE;
+  vrgInputs[ID_R_ing].dMag = 0.000000;
+  vrgInputs[ID_R_ing].dT0 = 0.000000;
+  vrgInputs[ID_R_ing].dTexp = 0.000000;
+  vrgInputs[ID_R_ing].dDecay = 0.000000;
+  vrgInputs[ID_R_ing].dTper = 0.000000;
+  vrgInputs[ID_R_ing].hMag = 0;
+  vrgInputs[ID_R_ing].hT0 = 0;
+  vrgInputs[ID_R_ing].hTexp = 0;
+  vrgInputs[ID_R_ing].hDecay = 0;
+  vrgInputs[ID_R_ing].hTper = 0;
+  vrgInputs[ID_R_ing].dVal = 0.0;
+  vrgInputs[ID_R_ing].nDoses = 0;
   PPM_per_mg_per_l = 72.0 / 0.488;
   mg_per_l_per_PPM = 1/PPM_per_mg_per_l;
   InhMag = 0.0;
@@ -402,7 +402,7 @@ void CalcDeriv (double  rgModelVars[], double  rgDerivs[], PDOUBLE pdTime)
 
   rgDerivs[ID_Q_pp] = Flow_pp * ( C_art - Cout_pp ) ;
 
-  rgDerivs[ID_Q_liv] = vrgInputs[ID_Q_ing].dVal + Flow_liv * ( C_art - Cout_liv ) - dQmet_liv ;
+  rgDerivs[ID_Q_liv] = vrgInputs[ID_R_ing].dVal + Flow_liv * ( C_art - Cout_liv ) - dQmet_liv ;
 
   rgDerivs[ID_Q_met] = dQmet_liv ;
 
