@@ -1,6 +1,6 @@
 /* modo.c
 
-   Copyright (c) 1993-2012. Free Software Foundation, Inc.
+   Copyright (c) 1993-2017. Free Software Foundation, Inc.
 
    This file is part of GNU MCSim.
 
@@ -17,14 +17,6 @@
    You should have received a copy of the GNU General Public License
    along with GNU MCSim; if not, see <http://www.gnu.org/licenses/>
 
-   -- Revisions -----
-     Logfile:  %F%
-    Revision:  %I%
-        Date:  %G%
-     Modtime:  %U%
-      Author:  @a
-   -- SCCS  ---------
-
    Output the model.c file.
 
    Modified on 07/07/97 by FB - added yourcode.h to WriteIncludes().
@@ -608,13 +600,12 @@ void TranslateID (PINPUTBUF pibDum, PFILE pfile, PSTR szLex, int iEqType)
 
 void TranslateEquation (PFILE pfile, PSTR szEqn, long iEqType)
 {
-#define RMARGIN 65
-
-  INPUTBUF ibDum;
-  PINPUTBUF pibDum = &ibDum;
-  PSTRLEX szLex;
-  int iType;
-  BOOL bDelayCall = FALSE;
+  INPUTBUF    ibDum;
+  PINPUTBUF   pibDum = &ibDum;
+  PSTRLEX     szLex;
+  PVMMAPSTRCT pvm = NULL;
+  int         iType;
+  BOOL        bDelayCall = FALSE;
 
   MakeStringBuffer (NULL, pibDum, szEqn);
 
@@ -626,18 +617,19 @@ void TranslateEquation (PFILE pfile, PSTR szEqn, long iEqType)
 
   do {
     if (iType == LX_IDENTIFIER) { // Process Identifier
-      if (bDelayCall) {  
+      if (bDelayCall) {
         // do not translate the 1st param of CalcDelay but check it
-        PVMMAPSTRCT pvm = NULL;
-        if (((pvm = GetVarPTR(vpvmGloVarList, szLex)) && 
-	     (TYPE(pvm) == ID_STATE)) || (TYPE(pvm) == ID_OUTPUT)) {
+        pvm = GetVarPTR(vpvmGloVarList, szLex);
+        if ( ( bForR && ((pvm && (TYPE(pvm) == ID_STATE)))) ||
+             (!bForR && ((pvm && (TYPE(pvm) == ID_STATE))   || 
+                         (TYPE(pvm) == ID_OUTPUT)))) {
           fprintf (pfile, "ID_%s", szLex);
-          // add the automatic time variable
-          fprintf (pfile, ", (*pdTime)");
-          bDelayCall = FALSE;
+          fprintf (pfile, ", (*pdTime)"); // add the automatic time variable
+          bDelayCall = FALSE; // turn delay context off
         }
         else
-          ReportError (pibDum, RE_EXPECTED | RE_FATAL, "state or output", NULL);
+          ReportError (pibDum, RE_LEXEXPECTED | RE_FATAL, 
+                       (bForR ? "state" : "state or output") , NULL);
       }
       else
         TranslateID (pibDum, pfile, szLex, iEqType);
@@ -655,7 +647,7 @@ void TranslateEquation (PFILE pfile, PSTR szEqn, long iEqType)
         fprintf (pfile, "%s", szLex);
     }
 
-    if (!bDelayCall) { // do not reset here if bDelayCall is TRUE
+    if (!bDelayCall) { // check delay context
       bDelayCall = (!strcmp("CalcDelay", szLex));
       bDelay = bDelay || bDelayCall;
     }
