@@ -21,13 +21,19 @@
  * Random number generator module: Two versions are provided. One uses the
    GNU Scientific Library (GSL). The other is independent of GSL.
 
-   The GSL version provides
+   The GSL version provides:
    Randoms(), which in fact call gsl_rng_uniform()
+   InitRandom(seed, f), which must be called to initializes the generator
+   SetSeed(seed), which sets the seed of Randoms()
+   GetSeed(seed), not implemented in fact and exits with an error message
 
-   The independent code provides two basic uniform random number
-   generators:
-   Randoms()        yielding uniform random variates between 0 and 1
-   RandomShuffle()  which shuffles the output of Randoms().
+   The independent (non-GSL) code provides two basic uniform random number
+   generators and associated functions:
+   Randoms(), yielding uniform random variates between 0 and 1
+   RandomShuffle(), which shuffles the output of Randoms().
+   InitRandom(seed, f), which initializes RandomShuffle()
+   SetSeed(seed), which sets the seed of Randoms()
+   GetSeed(seed), which gets the current seed
 
  * Other types of random variates generators are available. They call 
    Randoms() if they require a uniform variate:
@@ -69,17 +75,6 @@
    lnGamma(x)                                -- Natural log of gamma function
    lnDFBeta(x, alpha, beta, min, max)        -- Log of beta density
    piecewise(...)                            -- Piecewise function
-   SetSeed(seed)                             -- Sets the seed of Randoms
-   InitRandom(seed, f)                       -- Initializes the package
-
- * The random number generator must be initialized by providing a seed
-   to InitRandom(). A non-zero second argument to this function
-   instructs the random number generator to "warm up" by filling a
-   memory array used by RandomShuffle(). This also initializes a flag
-   used by the Normal() routine.
-
-   If the random number generator is not initialized before any of its
-   routines are called, it initializes itself with a default seed.
 
 */
 
@@ -90,22 +85,27 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef HAVE_LIBGSL
-#include <gsl/gsl_rng.h>
-#endif
-
 #include "hungtype.h"
 #include "lex.h"
 #include "lexerr.h"
 #include "random.h"
 
 
+/* ----------------------------------------------------------------------------
+   Globals/Externals
+*/
+
+static BOOL vbSwitchGauss = FALSE; /* Flag to reset switchG in NormalRandom */ 
+
+
 /* ----------------------------------------------------------------------------
    We have two versions of Randoms() depending whether we use gsl or not
 */
 
 #ifdef HAVE_LIBGSL
 
+#include <gsl/gsl_rng.h>
+
 /* ----------------------------------------------------------------------------
    GSL version, global definitions, private
 */
@@ -113,6 +113,34 @@
 static const gsl_rng_type * genType;
 static gsl_rng * rGenerator;
 
+/* ----------------------------------------------------------------------------
+   GetSeed
+
+   Not available if GSL is used. Issue an error message.
+*/
+
+double GetSeed (void)
+{
+  printf ("Error: the GetSeed() function is not available if GSL is used "
+          "- Exiting\n\n");
+  exit (0);
+}
+
+
+/* ----------------------------------------------------------------------------
+   SetSeed
+
+   Sets vRandRec.seed to given dSeed. Note that the seed is a long int.
+*/
+void SetSeed (double dSeed)
+{
+  
+  gsl_rng_set(rGenerator, (unsigned long int) dSeed);
+  vbSwitchGauss = FALSE; /* Force a reset of the normal variate sampler */
+  
+} /* SetSeed */
+
+
 /* ----------------------------------------------------------------------------
    Randoms, gsl version
 */
@@ -157,6 +185,8 @@ void InitRandom (double dSeed, int rdm_gen_name)
     printf ("\n* Using GNU Scientific Library (GSL) '%s' "
             "random number generator.\n\n", gsl_rng_name(rGenerator));
 
+    vbSwitchGauss = FALSE; /* Force a reset of the normal variate sampler */
+    
     /* next calls to InitRandoms will do nothing */
     bInit = 1;
   }
@@ -177,12 +207,10 @@ typedef struct tagRANDREC {
 
 
 static BOOL vbNoSeed = TRUE;       /* Flag to prevent use without seed */
-static BOOL vbSwitchGauss = FALSE; /* Flag to reset switchG in NormalRandom */ 
 static BOOL vbNotInitd = TRUE;     /* Flag to prevent use without initing */
 static RANDREC vRandRec;           /* Global random information shared by */
                                    /* all random number functions */
 
-
 /* ----------------------------------------------------------------------------
    GetSeed
 
@@ -279,7 +307,7 @@ void InitRandom (double dSeed, int bWarmUp)
 
    Randoms() returns random numbers between 0 and 1. The minimum
    returned value is 1/m and the maximum 1 - 1/m. The generator can
-   be initialized with InitRandom(). 
+   be initialized with InitRandom(). If not, it auto-initializes its seed.
 
    This generator should be correct on any system for which the
    representattion of reals uses at least a 32-bit mantissa, including
@@ -1294,7 +1322,7 @@ double lnDFBeta (double x, double alpha, double beta, double min, double max)
 /* ----------------------------------------------------------------------------
    lnDFNormal
    the log of the normal density function
-   0.9189385332046 is log(sqrt(2*PI))
+   0.918938533204672669541 is log(sqrt(2*PI))
 */
 double lnDFNormal (double x, double mu, double sd)
 {
@@ -1303,7 +1331,7 @@ double lnDFNormal (double x, double mu, double sd)
     exit (0);
   }
 
-  return ( -0.9189385332046 - log (sd) - 0.5 * pow ((mu - x)/sd, 2) );
+  return ( -0.918938533204672669541 - log (sd) - 0.5 * pow ((mu - x)/sd, 2) );
 }
 
 
