@@ -42,21 +42,21 @@
 */
 
 /* Version and copyright */
-#define VSZ_VERSION "v6.0.0"
+#define VSZ_VERSION "v6.0.1"
 #define VSZ_COPYRIGHT "Copyright (c) 1993-2018 Free Software Foundation, Inc."
 
 /* These are potential array size problems.
    Other maximum sizes are MAX_EQN and MAX_LEX in lex.h */
 
-#define MAX_LEVELS            10   /* for now; actual possible is 255 */
-#define MAX_INSTANCES         200  /* allowable instances of `Level' at any
-                                      depth and max number of experiments */
-#define LSODES_IWORKSIZE      300  /* Lsodes tells if this is not big enough */
-#define LSODES_RWORKSIZE      6000 /* Idem */
-#define ARGS_MAX              8    /* Maximum number of args to lex */
-                                   /* Used in allocating argument strings */
-#define MAX_PRINT_VARS        200  /* Arbitrary */
-#define MAX_FILENAMESIZE      200  /* Arbitrary */
+#define MAX_LEVELS            10    /* for now; actual possible is 255 */
+#define MAX_INSTANCES         20000 /* allowable instances of `Level' at any
+                                       depth and max number of experiments */
+#define LSODES_IWORKSIZE      1000  /* Lsodes tells if it needs more */
+#define LSODES_RWORKSIZE      60000 /* Idem */
+#define ARGS_MAX              8     /* Maximum number of args to lex */
+                                    /* Used in allocating argument strings */
+#define MAX_PRINT_VARS        200   /* Arbitrary */
+#define MAX_FILENAMESIZE      200   /* Arbitrary */
 
 /* Keyword Map constants */
 
