@@ -760,7 +760,7 @@ BOOL GetPrint (PINPUTBUF pibIn, PSTR szLex, POUTSPEC pos)
 
           if (i == (iUB - 1))
             GetOptPunct (pibIn, szTmp, ',');
-        } /* end for i*/
+        } /* end for i */
       } /* end else */
     } /* end for ever */
 
@@ -1863,10 +1863,12 @@ int GetDistribParam (PINPUTBUF pibIn, PSTR szLex, PLIST plist, int n,
 */
 int GetSetPointsSpec (PINPUTBUF pibIn, PANALYSIS  panal, PSTR szLex)
 {
-  PMCVAR pMCVar;
-  HVAR hvar;
-  int iErr = 0;
-  int iNLI;
+  PMCVAR  pMCVar;
+  PSTRLEX szTmp;
+  HVAR    hvar;
+  int     iErr = 0;
+  int     iNLI;
+  long    j, iLB, iUB;
 
   /* MonteCarlo sampling can be mixed with SetPoints sampling if Distrib
      specs appear after the SetPoint spec */
@@ -1899,26 +1901,49 @@ int GetSetPointsSpec (PINPUTBUF pibIn, PANALYSIS  panal, PSTR szLex)
   GetOptPunct (pibIn, szLex, ',');
   if ((iErr = ENextLex (pibIn, szLex, LX_INTEGER)))
     goto Exit_GetSetPointsSpec;
+
   panal->mc.nRuns = atol (szLex);
 
   /* Try to get identifier list */
-
-  /* FB 20/11/96 removed this because it gives errors if only a comma
-     separates the number of runs from the list of params :
-     GetOptPunct (pibIn, szLex, ','); */
   while ((iNLI=NextListItem (pibIn, szLex, LX_IDENTIFIER, 1, CH_RPAREN)) > 0) {
-    hvar = GetVarHandle(szLex);
-    if ((iErr = (!hvar || IsInput(hvar))))
-      break; /* Is this reported ? */
+    /* check if szLex is a scalar or an array and act accordingly */
+    iLB = iUB = -1;
+    if (GetPunct (pibIn, szTmp, '[')) /* array found, read bounds */
+      GetArrayBounds (pibIn, &iLB, &iUB);
 
-    if ( !(pMCVar = (PMCVAR) malloc (sizeof(MCVAR))))
-      ReportError (pibIn, RE_OUTOFMEM | RE_FATAL, "GetSetPointsSpec", NULL);
+    if (iUB == -1) { /* scalar, store and continue */
+      hvar = GetVarHandle(szLex);
+      if ((iErr = (!hvar || IsInput(hvar))))
+        break; /* will generate an error message */
 
-    pMCVar->hvar = hvar;
-    pMCVar->iType = MCV_SETPOINTS;
-    pMCVar->dParm[2] = pMCVar->dParm[3] = 0.0;
+      if ( !(pMCVar = (PMCVAR) malloc (sizeof(MCVAR))))
+        ReportError (pibIn, RE_OUTOFMEM | RE_FATAL, "GetSetPointsSpec", NULL);
 
-    QueueListItem (panal->mc.plistMCVars, pMCVar);
+      pMCVar->hvar = hvar;
+      pMCVar->iType = MCV_SETPOINTS;
+      pMCVar->dParm[2] = pMCVar->dParm[3] = 0.0;
+
+      QueueListItem (panal->mc.plistMCVars, pMCVar);
+    }
+    else { /* array */
+
+      for (j = iLB; j < iUB; j++) {
+        sprintf(szTmp, "%s_%ld", szLex, j); /* create names */          
+
+        hvar = GetVarHandle (szTmp);
+        if ((iErr = (!hvar || IsInput(hvar))))
+          break; /* will generate an error message */
+
+        if ( !(pMCVar = (PMCVAR) malloc (sizeof(MCVAR))))
+          ReportError(pibIn, RE_OUTOFMEM | RE_FATAL, "GetSetPointsSpec", NULL);
+
+        pMCVar->hvar = hvar;
+        pMCVar->iType = MCV_SETPOINTS;
+        pMCVar->dParm[2] = pMCVar->dParm[3] = 0.0;
+
+        QueueListItem (panal->mc.plistMCVars, pMCVar);
+      }
+    } /* end else */
 
   } /* while */
 
@@ -1933,7 +1958,7 @@ int GetSetPointsSpec (PINPUTBUF pibIn, PANALYSIS  panal, PSTR szLex)
   }
   
   if (!iNLI) /* List terminator */
-    iErr = EGetPunct (pibIn, szLex, CH_RPAREN) || InitSetPoints (&panal->mc);
+    iErr = ((szTmp[0] != CH_RPAREN) && (EGetPunct (pibIn, szLex, CH_RPAREN))) || InitSetPoints (&panal->mc);
   else {
     iErr = TRUE;
     ReportError (pibIn, RE_LEXEXPECTED, "identifier", szLex);
@@ -2024,7 +2049,7 @@ BOOL GetParmMod (PINPUTBUF pibIn, PSTRLEX szLex)
     if (!GetOptPunct (pibIn, szPunct, '=')) { /* Try to get '=' */
       iErr = szPunct[1] = '=';
       ReportError (pibIn, RE_EXPECTED, szPunct, NULL);
-    } /* if */
+    }
 
     else if (IsInput (hvar)) { /* Process INPUT */
       if ( !(pvarmod->uvar.pifn = (PIFN) malloc (sizeof(IFN))))
@@ -2036,12 +2061,11 @@ BOOL GetParmMod (PINPUTBUF pibIn, PSTRLEX szLex)
         free (pvarmod->uvar.pifn); /* Cleanup if error */
         pvarmod->uvar.pifn = NULL;
       }
-    } /* if */
-
+    } /* else if */
     else { /* PARM, STATE, etc */
       if (!(iErr = ENextLex(pibIn, szLex, LX_NUMBER)))
         pvarmod->uvar.dVal = atof(szLex);
-    } /* else */
+    }
 
     if (!iErr) { /* No errors, add mod to list */
       if(panal->iCurrentDepth == 0 || panal->wContext == CN_EXPERIMENT)
@@ -2096,11 +2120,10 @@ BOOL GetParmMod2 (PINPUTBUF pibIn, PSTRLEX szLex, PSTREQN szEqn)
         free (pvarmod->uvar.pifn); /* Cleanup if error */
         pvarmod->uvar.pifn = NULL;
       }
-    } /* if */
-
+    }
     else { /* PARM, STATE, etc */
       pvarmod->uvar.dVal = atof(szEqn);
-    } /* else */
+    }
 
     if (!iErr) { /* No errors, add mod to list */
       if(panal->iCurrentDepth == 0 || panal->wContext == CN_EXPERIMENT)
